@@ -27,9 +27,8 @@ from __future__ import absolute_import
 
 __all__ = ["TaurusPlot"]
 
-from future.utils import string_types
 import copy
-from taurus.external.qt import QtGui, Qt
+from taurus.external.qt import QtGui, PYSIDE2
 from taurus.core.util.containers import LoopList
 from taurus.core.util.log import Logger
 from taurus.qt.qtcore.configuration import BaseConfigurableClass
@@ -62,8 +61,8 @@ class TaurusPlot(PlotWidget, BaseConfigurableClass):
     """
 
     def __init__(self, parent=None, **kwargs):
-        if Qt.QT_VERSION < 0x050000:
-            # Workaround for issue when using super with pyqt<5
+        if PYSIDE2:
+            # Workaround for https://bugreports.qt.io/browse/PYSIDE-1564
             BaseConfigurableClass.__init__(self)
             PlotWidget.__init__(self, parent=parent, **kwargs)
         else:
@@ -125,20 +124,6 @@ class TaurusPlot(PlotWidget, BaseConfigurableClass):
         self.registerConfigDelegate(legend_tool, "legend")
         self.registerConfigDelegate(inspector_tool, "inspector")
 
-    # --------------------------------------------------------------------
-    # workaround for bug in pyqtgraph v<=0.10.0, already fixed in
-    # https://github.com/pyqtgraph/pyqtgraph/commit/52754d4859
-    # TODO: remove this once pyqtgraph v>0.10 is released
-    def __getattr__(self, item):
-        try:
-            return PlotWidget.__getattr__(self, item)
-        except NameError:
-            raise AttributeError(
-                "{} has no attribute {}".format(self.__class__.__name__, item)
-            )
-
-    # --------------------------------------------------------------------
-
     def __getitem__(self, idx):
         """
         Provides a list-like interface: items can be accessed using slice
@@ -149,17 +134,20 @@ class TaurusPlot(PlotWidget, BaseConfigurableClass):
     def __len__(self):
         return len(self.getPlotItem().listDataItems())
 
+    def __bool__(self):
+        return True
+
     def setModel(self, names):
         """Reimplemented to delegate to the model chooser"""
         # support passing a string in names
-        if isinstance(names, string_types):
+        if isinstance(names, str):
             names = [names]
         self._model_chooser_tool.updateModels(names)
 
     def addModels(self, names):
         """Reimplemented to delegate to the  model chooser"""
         # support passing a string in names
-        if isinstance(names, string_types):
+        if isinstance(names, str):
             names = [names]
         self._model_chooser_tool.addModels(names)
 
