@@ -25,8 +25,6 @@
 
 __all__ = ["TaurusModelChooserTool", "TaurusImgModelChooserTool"]
 
-from builtins import bytes
-from future.utils import string_types
 
 from taurus.external.qt import Qt
 from taurus.core import TaurusElementType
@@ -113,13 +111,6 @@ class TaurusModelChooserTool(Qt.QAction):
         for k, v in currentModelItems.items():
             # v.getViewBox().removeItem(v)  # TODO: maybe needed for Y2
             self.plot_item.removeItem(v)
-            # -------------------------------------------------
-            # Workaround for bug in pyqtgraph 0.10.0
-            # (which is fixed in pyqtgraph's commit ee0ea5669)
-            # TODO: remove this lines when pyqtgraph > 0.10.0 is released
-            if self.legend is not None:
-                self.legend.removeItem(v.name())
-            # -------------------------------------------------
 
         # Add all curves (creating those that did not exist previously)
         # respecting the z-order
@@ -298,16 +289,24 @@ class TaurusXYModelChooserTool(Qt.QAction, BaseConfigurableClass):
 
     def _onTriggered(self):
         oldconfs = self._getTaurusPlotDataItemConfigs().values()
-        newconfs, ok = TaurusItemConfDlg.showDlg(
+        dlg = Qt.QDialog(self.parent())
+        dlg.setWindowTitle("Curves Selection")
+        layout = Qt.QVBoxLayout()
+        w = TaurusItemConfDlg(
             parent=self.parent(),
-            taurusItemConf=oldconfs,
-            showXCol=self._showX,
+            taurusItemsConf=oldconfs,
+            showXcol=self._showX,
         )
+        layout.addWidget(w)
+        dlg.setLayout(layout)
+        w.applied.connect(self._onDlgApplied)
+        w.ui.cancelBT.clicked.connect(dlg.close)
+        dlg.exec_()
 
-        if ok:
-            xy_names = [(c.xModel, c.yModel) for c in newconfs]
-            self.updateModels(xy_names)
-            # TODO: apply configurations too
+    def _onDlgApplied(self):
+        newconfs = self.sender().getItemConfs()
+        xy_names = [(c.xModel, c.yModel) for c in newconfs]
+        self.updateModels(xy_names)
 
     def _getTaurusPlotDataItemConfigs(self):
         """Get all the TaurusItemConf of the existing TaurusPlotDataItems
@@ -320,8 +319,12 @@ class TaurusXYModelChooserTool(Qt.QAction, BaseConfigurableClass):
                 xmodel, ymodel = curve.getFullModelNames()
                 name = curve.name()
                 # ugly hack for TaurusTrendset, which forces .name() ->None
-                if name is None and hasattr(curve, "base_name"):
-                    name = curve.base_name()
+                if (
+                    name is None
+                    and hasattr(curve, "base_name")
+                    and hasattr(curve, "_getCurveNames")
+                ):
+                    name = [curve.base_name()] + curve._getCurveNames()
                 c = TaurusItemConf(YModel=ymodel, XModel=xmodel, name=name)
                 itemconfigs[(xmodel, ymodel)] = c
         return itemconfigs
@@ -352,15 +355,17 @@ class TaurusXYModelChooserTool(Qt.QAction, BaseConfigurableClass):
         events to TaurusXYModelChooserTool
         """
         if source is self.parent():
-            if event.type() == Qt.QEvent.DragEnter:
+            t = event.type()
+            if t == Qt.QEvent.DragEnter:
                 event.acceptProposedAction()
                 return True
-
-            if event.type() == Qt.QEvent.Drop:
+            elif t == Qt.QEvent.Drop:
                 event.acceptProposedAction()
                 return self._dropMimeData(event.mimeData())
+            else:
+                return False
 
-        return self.parent().eventFilter(source, event)
+        return Qt.QAction.eventFilter(self, source, event)
 
     def getModelNames(self):
         """
@@ -420,7 +425,7 @@ class TaurusXYModelChooserTool(Qt.QAction, BaseConfigurableClass):
         for xy_name in xy_names:
             # each member of xy_names can be yname or a (xname, yname[, cname])
             # tuple
-            if isinstance(xy_name, string_types):
+            if isinstance(xy_name, str):
                 xname, yname, cname = None, xy_name, None
             else:
                 try:
@@ -472,9 +477,9 @@ def _demo_ModelChooser():
     import sys
     import numpy
     import pyqtgraph as pg
-    from taurus.qt.qtgui.tpg import TaurusModelChooserTool
+    from taurus_pyqtgraph import TaurusModelChooserTool
     from taurus.qt.qtgui.application import TaurusApplication
-    from taurus.qt.qtgui.tpg import TaurusPlotDataItem
+    from taurus_pyqtgraph import TaurusPlotDataItem
 
     app = TaurusApplication()
 
@@ -508,7 +513,7 @@ def _demo_ModelChooser():
 
 def _demo_ModelChooserImage():
     import sys
-    from taurus.qt.qtgui.tpg import TaurusImgModelChooserTool, TaurusImageItem
+    from taurus_pyqtgraph import TaurusImgModelChooserTool, TaurusImageItem
     from taurus.qt.qtgui.application import TaurusApplication
     import pyqtgraph as pg
 
